
%% LOAD PROBLEM DATA

clear all; close all; clc

% define the truss structure
% have a look at load_data.m to get a rough understanding
D = load_data;                          

m = numel(D.A);                         % number of bars
n = size(D.Coord,2);                    % number of nodes

% calculate stiffness matrix
[KLMI, Le] = calculate_stiffness(D);

%% OPTIMIZE STRUCTURE

% define area variables
x = sdpvar(m,1);                % this is a YALMIP variable     

% form LMI using only the invertible part of K
Klmi = KLMI(:,:,1)*x(1);
for i = 2:size(KLMI,3)
    Klmi = Klmi + KLMI(:,:,i)*x(i);
end

alpha = sdpvar(1,1);
M     = [alpha D.Fext';D.Fext Klmi];

constr = [];
constr = [constr; sum(x.*Le) <= 1e5];
constr = [constr; M >= 0];
constr = [constr; x >= 0];
constr = [constr; x <= 200];
%constr = [constr; x(3)==0];

% tell YALMIP to use SDPT3 as solver and pass some options
options = sdpsettings('solver', 'SDPT3','verbose',2,'sdpt3.maxit',100);

% tell YALMIP to actually solve the optimization problem
optimize(constr, alpha, options);

disp(' ')
disp('Calculated diameters:')
% you can access the optimal values of your yalmip variables like this
disp(double(x))                 
%% CHECK AND PLOT RESUTS

disp(' ')
disp('Sum of cross-sectional areas:')
disp(sum(double(x).*Le))

% plot structure
plot_structure(D, double(x)')